@@ -42,6 +42,9 @@
 #' @param hakn A logical indicating whether the method by Hartung and
 #'   Knapp should be used to adjust test statistics and confidence
 #'   intervals.
+#' @param adhoc.hakn A character string indicating whether an \emph{ad
+#'   hoc} variance correction should be applied in the case of an
+#'   arbitrarily small Hartung-Knapp variance estimate, see Details.
 #' @param method.tau A character string indicating which method is
 #'   used to estimate the between-study variance \eqn{\tau^2} and its
 #'   square root \eqn{\tau}. Either \code{"DL"}, \code{"PM"},
@@ -215,10 +218,26 @@
 #' treatment estimate. Simulation studies (Hartung and Knapp, 2001;
 #' IntHout et al., 2014; Langan et al., 2019) show improved coverage
 #' probabilities compared to the classic random effects
-#' method. However, in rare settings with very homogeneous treatment
-#' estimates, the Hartung-Knapp method can be anti-conservative
-#' (Wiksten et al., 2016). The Hartung-Knapp method is used if
-#' argument \code{hakn = TRUE}.
+#' method.
+#'
+#' In rare settings with very homogeneous treatment estimates, the
+#' Hartung-Knapp variance estimate can be arbitrarily small resulting
+#' in a very narrow confidence interval (Knapp and Hartung, 2003;
+#' Wiksten et al., 2016). In such cases, an \emph{ad hoc} variance
+#' correction has been proposed by utilising the variance estimate
+#' from the classic random effects model (Knapp and Hartung,
+#' 2003). Argument \code{adhoc.hakn} can be used to choose the
+#' \emph{ad hoc} method:
+#' \tabular{ll}{
+#' \bold{Argument}\tab \bold{\emph{Ad hoc} method} \cr 
+#' \code{adhoc.hakn = ""}\tab not used \cr
+#' \code{adhoc.hakn = "se"}\tab used if HK standard error is smaller than
+#'  standard error \cr
+#'  \tab from classic random effects model (Knapp and Hartung, 2003) \cr
+#' \code{adhoc.hakn = "ci"}\tab used if HK confidence interval is
+#'  narrower than CI from \cr
+#'  \tab classic random effects model with DL estimator (IQWiG, 2020)
+#' }
 #' }
 #' 
 #' \subsection{Prediction interval}{
@@ -270,7 +289,7 @@
 #' \item{comb.fixed, comb.random,}{As defined above.}
 #' \item{overall, overall.hetstat,}{As defined above.}
 #' \item{pooledvar, method.smd, sd.glass,}{As defined above.}
-#' \item{hakn, method.tau, method.tau.ci,}{As defined above.}
+#' \item{hakn, adhoc.hakn, method.tau, method.tau.ci,}{As defined above.}
 #' \item{tau.preset, TE.tau, method.bias,}{As defined above.}
 #' \item{tau.common, title, complab, outclab,}{As defined above.}
 #' \item{label.e, label.c, label.left, label.right,}{As defined
@@ -472,6 +491,10 @@
 #' \emph{BMC Medical Research Methodology},
 #' \bold{14}, 25
 #' 
+#' IQWiG (2020):
+#' General Methods: Draft of Version 6.0.
+#' \url{https://www.iqwig.de/en/methods/methods-paper.3020.html}
+#' 
 #' Knapp G & Hartung J (2003):
 #' Improved tests for a random effects meta-regression with a single
 #' covariate.
@@ -571,7 +594,7 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
                      overall = comb.fixed | comb.random,
                      overall.hetstat = comb.fixed | comb.random,
                      ##
-                     hakn = gs("hakn"),
+                     hakn = gs("hakn"), adhoc.hakn = gs("adhoc.hakn"),
                      method.tau = gs("method.tau"),
                      method.tau.ci = if (method.tau == "DL") "J" else "QP",
                      tau.preset = NULL, TE.tau = NULL,
@@ -613,6 +636,7 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
   chklogical(overall.hetstat)
   ##
   chklogical(hakn)
+  adhoc.hakn <- setchar(adhoc.hakn, .settings$adhoc4hakn)
   method.tau <- setchar(method.tau, .settings$meth4tau)
   method.tau.ci <- setchar(method.tau.ci, .settings$meth4tau.ci)
   chklogical(tau.common)
@@ -973,7 +997,7 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
                overall = overall,
                overall.hetstat = overall.hetstat,
                ##
-               hakn = hakn,
+               hakn = hakn, adhoc.hakn = adhoc.hakn,
                method.tau = method.tau, method.tau.ci = method.tau.ci,
                tau.preset = tau.preset,
                TE.tau = TE.tau,
