@@ -27,10 +27,14 @@
 #'   Knapp should be used to adjust test statistics and confidence
 #'   intervals.
 #' @param method.tau A character string indicating which method is
-#'   used to estimate the between-study variance \eqn{\tau^2}. Either
-#'   \code{"DL"}, \code{"PM"}, \code{"REML"}, \code{"ML"},
-#'   \code{"HS"}, \code{"SJ"}, \code{"HE"}, or \code{"EB"}, can be
-#'   abbreviated.
+#'   used to estimate the between-study variance \eqn{\tau^2} and its
+#'   square root \eqn{\tau}. Either \code{"DL"}, \code{"PM"},
+#'   \code{"REML"}, \code{"ML"}, \code{"HS"}, \code{"SJ"},
+#'   \code{"HE"}, or \code{"EB"}, can be abbreviated.
+#' @param method.tau.ci A character string indicating which method is
+#'   used to estimate the confidence interval of \eqn{\tau^2} and
+#'   \eqn{\tau}. Either \code{"QP"}, \code{"BJ"}, or \code{"J"}, or
+#'   \code{""}, can be abbreviated.
 #' @param tau.common A logical indicating whether tau-squared should
 #'   be the same across subgroups.
 #' @param prediction A logical indicating whether a prediction
@@ -68,8 +72,9 @@
 #' 
 #' This wrapper function can be used to perform meta-analysis for a
 #' single outcome of a Cochrane Intervention review. Internally, R
-#' functions \code{metabin}, \code{metacont}, and \code{metagen} are
-#' called - depending on the definition of the outcome in RevMan 5.
+#' functions \code{\link{metabin}}, \code{\link{metacont}}, and
+#' \code{\link{metagen}} are called - depending on the definition of
+#' the outcome in RevMan 5.
 #' 
 #' Note, it is recommended to choose the RevMan 5 settings before
 #' executing \code{metacr}, i.e., \code{settings.meta("revman5")}.
@@ -132,6 +137,7 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                    ##
                    hakn = FALSE,
                    method.tau = "DL",
+                   method.tau.ci = if (method.tau == "DL") "J" else "QP",
                    tau.common = FALSE,
                    ##
                    prediction = gs("prediction"),
@@ -159,8 +165,8 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
   chklevel(level.comb)
   ##
   chklogical(hakn)
-  method.tau <- setchar(method.tau,
-                        c("DL", "PM", "REML", "ML", "HS", "SJ", "HE", "EB"))
+  method.tau <- setchar(method.tau, .settings$meth4tau)
+  method.tau.ci <- setchar(method.tau.ci, .settings$meth4tau.ci)
   chklogical(tau.common)
   ##
   chklogical(prediction)
@@ -287,7 +293,8 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                       sm = sm, method = method, studlab = studlab,
                       data = x[sel, varnames],
                       comb.fixed = comb.fixed, comb.random = comb.random,
-                      method.tau = method.tau, hakn = hakn,
+                      hakn = hakn,
+                      method.tau = method.tau, method.tau.ci = method.tau.ci,
                       tau.common = tau.common,
                       level = level, level.comb = level.comb,
                       prediction = prediction, level.predict = level.predict,
@@ -299,14 +306,16 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                       complab = complab, outclab = outclab,
                       label.e = label.e, label.c = label.c,
                       label.left = label.left, label.right = label.right,
-                      RR.cochrane = TRUE, warn = warn,
-                      keepdata = keepdata)
+                      RR.Cochrane = TRUE,
+                      Q.Cochrane = if (method.tau == "DL") TRUE else FALSE,
+                      warn = warn, keepdata = keepdata)
       else
         m1 <- metabin(event.e, n.e, event.c, n.c,
                       sm = sm, method = method, studlab = studlab,
                       data = x[sel, varnames],
                       comb.fixed = comb.fixed, comb.random = comb.random,
-                      method.tau = method.tau, hakn = hakn,
+                      hakn = hakn,
+                      method.tau = method.tau, method.tau.ci = method.tau.ci,
                       tau.common = tau.common,
                       level = level, level.comb = level.comb,
                       prediction = prediction, level.predict = level.predict,
@@ -318,8 +327,9 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                       complab = complab, outclab = outclab,
                       label.e = label.e, label.c = label.c,
                       label.left = label.left, label.right = label.right,
-                      RR.cochrane = TRUE, warn = warn,
-                      keepdata = keepdata)
+                      RR.Cochrane = TRUE,
+                      Q.Cochrane = if (method.tau == "DL") TRUE else FALSE,
+                      warn = warn, keepdata = keepdata)
     }
     ##
     if (type == "C")
@@ -328,7 +338,8 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                      sm = sm, studlab = studlab,
                      data = x[sel, varnames],
                      comb.fixed = comb.fixed, comb.random = comb.random,
-                     method.tau = method.tau, hakn = hakn,
+                     hakn = hakn,
+                     method.tau = method.tau, method.tau.ci = method.tau.ci,
                      tau.common = tau.common,
                      level = level, level.comb = level.comb,
                      prediction = prediction, level.predict = level.predict,
@@ -346,7 +357,8 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     sm = sm, studlab = studlab,
                     data = x[sel, varnames],
                     comb.fixed = comb.fixed, comb.random = comb.random,
-                    method.tau = method.tau, hakn = hakn,
+                    hakn = hakn,
+                    method.tau = method.tau, method.tau.ci = method.tau.ci,
                     tau.common = tau.common,
                     level = level, level.comb = level.comb,
                     prediction = prediction, level.predict = level.predict,
@@ -365,7 +377,8 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     sm = sm, studlab = studlab,
                     data = x[sel, varnames],
                     comb.fixed = comb.fixed, comb.random = comb.random,
-                    method.tau = method.tau, hakn = hakn,
+                    hakn = hakn,
+                    method.tau = method.tau, method.tau.ci = method.tau.ci,
                     tau.common = tau.common,
                     level = level, level.comb = level.comb,
                     prediction = prediction, level.predict = level.predict,
@@ -386,7 +399,8 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     sm = sm, studlab = studlab,
                     data = x[sel, varnames],
                     comb.fixed = comb.fixed, comb.random = comb.random,
-                    method.tau = method.tau, hakn = hakn,
+                    hakn = hakn,
+                    method.tau = method.tau, method.tau.ci = method.tau.ci,
                     tau.common = tau.common,
                     level = level, level.comb = level.comb,
                     prediction = prediction, level.predict = level.predict,
@@ -413,7 +427,8 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                       sm = sm, method = method, studlab = studlab,
                       data = x[sel, varnames],
                       comb.fixed = comb.fixed, comb.random = comb.random,
-                      method.tau = method.tau, hakn = hakn,
+                      hakn = hakn,
+                      method.tau = method.tau, method.tau.ci = method.tau.ci,
                       tau.common = tau.common,
                       level = level, level.comb = level.comb,
                       prediction = prediction, level.predict = level.predict,
@@ -422,14 +437,16 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                       complab = complab, outclab = outclab,
                       label.e = label.e, label.c = label.c,
                       label.left = label.left, label.right = label.right,
-                      RR.cochrane = TRUE, warn = warn,
-                      keepdata = keepdata)
+                      RR.Cochrane = TRUE,
+                      Q.Cochrane = if (method.tau == "DL") TRUE else FALSE,
+                      warn = warn, keepdata = keepdata)
       else
         m1 <- metabin(event.e, n.e, event.c, n.c,
                       sm = sm, method = method, studlab = studlab,
                       data = x[sel, varnames],
                       comb.fixed = comb.fixed, comb.random = comb.random,
-                      method.tau = method.tau, hakn = hakn,
+                      hakn = hakn,
+                      method.tau = method.tau, method.tau.ci = method.tau.ci,
                       tau.common = tau.common,
                       level = level, level.comb = level.comb,
                       prediction = prediction, level.predict = level.predict,
@@ -438,8 +455,9 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                       complab = complab, outclab = outclab,
                       label.e = label.e, label.c = label.c,
                       label.left = label.left, label.right = label.right,
-                      RR.cochrane = TRUE, warn = warn,
-                      keepdata = keepdata)
+                      RR.Cochrane = TRUE,
+                      Q.Cochrane = if (method.tau == "DL") TRUE else FALSE,
+                      warn = warn, keepdata = keepdata)
     }
     ##
     if (type == "C")
@@ -448,7 +466,8 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                      sm = sm, studlab = studlab,
                      data = x[sel, varnames],
                      comb.fixed = comb.fixed, comb.random = comb.random,
-                     method.tau = method.tau, hakn = hakn,
+                     hakn = hakn,
+                     method.tau = method.tau, method.tau.ci = method.tau.ci,
                      tau.common = tau.common,
                      level = level, level.comb = level.comb,
                      prediction = prediction, level.predict = level.predict,
@@ -463,7 +482,8 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     sm = sm, studlab = studlab,
                     data = x[sel, varnames],
                     comb.fixed = comb.fixed, comb.random = comb.random,
-                    method.tau = method.tau, hakn = hakn,
+                    hakn = hakn,
+                    method.tau = method.tau, method.tau.ci = method.tau.ci,
                     tau.common = tau.common,
                     level = level, level.comb = level.comb,
                     prediction = prediction, level.predict = level.predict,
@@ -479,7 +499,8 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     sm = sm, studlab = studlab,
                     data = x[sel, varnames],
                     comb.fixed = comb.fixed, comb.random = comb.random,
-                    method.tau = method.tau, hakn = hakn,
+                    hakn = hakn,
+                    method.tau = method.tau, method.tau.ci = method.tau.ci,
                     tau.common = tau.common,
                     level = level, level.comb = level.comb,
                     prediction = prediction, level.predict = level.predict,
@@ -497,7 +518,8 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     sm = sm, studlab = studlab,
                     data = x[sel, varnames],
                     comb.fixed = comb.fixed, comb.random = comb.random,
-                    method.tau = method.tau, hakn = hakn,
+                    hakn = hakn,
+                    method.tau = method.tau, method.tau.ci = method.tau.ci,
                     tau.common = tau.common,
                     level = level, level.comb = level.comb,
                     prediction = prediction, level.predict = level.predict,
