@@ -70,6 +70,11 @@
 #' @param hakn A logical indicating whether method by Hartung and
 #'   Knapp should be used to adjust test statistics and confidence
 #'   intervals.
+#' @param adhoc.hakn A character string indicating whether an \emph{ad
+#'   hoc} variance correction should be applied in the case of an
+#'   arbitrarily small Hartung-Knapp variance estimate. Either
+#'   \code{""}, \code{"se"}, or \code{"ci"} (see Details), can be
+#'   abbreviated.
 #' @param method.tau A character string indicating which method is
 #'   used to estimate the between-study variance \eqn{\tau^2} and its
 #'   square root \eqn{\tau}. Either \code{"DL"}, \code{"PM"},
@@ -281,9 +286,23 @@
 #' 2001a,b; IntHout et al., 2014; Langan et al., 2019) show improved
 #' coverage probabilities compared to the classic random effects
 #' method. However, in rare settings with very homogeneous treatment
-#' estimates, the Hartung-Knapp method can be anti-conservative
-#' (Wiksten et al., 2016). The Hartung-Knapp method is used if
-#' argument \code{hakn = TRUE}.
+#' estimates, the Hartung-Knapp (HK) variance estimate can be
+#' arbitrarily small resulting in a very narrow confidence interval
+#' (Knapp and Hartung, 2003; Wiksten et al., 2016). In such cases, an
+#' \emph{ad hoc} variance correction has been proposed by utilising
+#' the variance estimate from the classic random effects model (Knapp
+#' and Hartung, 2003). Argument \code{adhoc.hakn} can be used to
+#' choose the \emph{ad hoc} method:
+#' \tabular{ll}{
+#' \bold{Argument}\tab \bold{\emph{Ad hoc} method} \cr 
+#' \code{adhoc.hakn = ""}\tab not used \cr
+#' \code{adhoc.hakn = "se"}\tab used if HK standard error is smaller than
+#'  standard error \cr
+#'  \tab from classic random effects model (Knapp and Hartung, 2003) \cr
+#' \code{adhoc.hakn = "ci"}\tab used if HK confidence interval is
+#'  narrower than CI from \cr
+#'  \tab classic random effects model with DL estimator (IQWiG, 2020)
+#' }
 #' }
 #' 
 #' \subsection{Prediction interval}{
@@ -378,7 +397,7 @@
 #' \item{sm, level, level.comb,}{As defined above.}
 #' \item{comb.fixed, comb.random,}{As defined above.}
 #' \item{overall, overall.hetstat,}{As defined above.}
-#' \item{hakn, method.tau, method.tau.ci,}{As defined above.}
+#' \item{hakn, adhoc.hakn, method.tau, method.tau.ci,}{As defined above.}
 #' \item{tau.preset, TE.tau, method.bias,}{As defined above.}
 #' \item{tau.common, title, complab, outclab,}{As defined above.}
 #' \item{label.e, label.c, label.left, label.right,}{As defined
@@ -577,6 +596,10 @@
 #' standard DerSimonian-Laird method.
 #' \emph{BMC Medical Research Methodology},
 #' \bold{14}, 25
+#' 
+#' IQWiG (2020):
+#' General Methods: Draft of Version 6.0.
+#' \url{https://www.iqwig.de/en/methods/methods-paper.3020.html}
 #'
 #' Jackson D (2013):
 #' Confidence intervals for the between-study variance in random
@@ -585,6 +608,12 @@
 #' \emph{Research Synthesis Methods},
 #' \bold{4}, 220--229
 #' 
+#' Knapp G & Hartung J (2003):
+#' Improved tests for a random effects meta-regression with a single
+#' covariate.
+#' \emph{Statistics in Medicine},
+#' \bold{22}, 2693--710
+#' 
 #' Langan D, Higgins JPT, Jackson D, Bowden J, Veroniki AA,
 #' Kontopantelis E, et al. (2019):
 #' A comparison of heterogeneity variance estimators in simulated
@@ -714,7 +743,7 @@ metagen <- function(TE, seTE, studlab,
                     overall = comb.fixed | comb.random,
                     overall.hetstat = comb.fixed | comb.random,
                     ##
-                    hakn = gs("hakn"),
+                    hakn = gs("hakn"), adhoc.hakn = gs("adhoc.hakn"),
                     method.tau = gs("method.tau"),
                     method.tau.ci = if (method.tau == "DL") "J" else "QP",
                     tau.preset = NULL, TE.tau = NULL,
@@ -767,6 +796,7 @@ metagen <- function(TE, seTE, studlab,
   chklogical(overall.hetstat)
   ##
   chklogical(hakn)
+  adhoc.hakn <- setchar(adhoc.hakn, .settings$adhoc4hakn)
   method.tau <- setchar(method.tau, .settings$meth4tau)
   method.tau.ci <- setchar(method.tau.ci, .settings$meth4tau.ci)
   chklogical(tau.common)
@@ -1448,6 +1478,8 @@ metagen <- function(TE, seTE, studlab,
   ##
   k <- sum(!is.na(seTE[!exclude]))
   ##
+  seTE.random.hakn.orig <- NULL
+  ##
   if (k == 0) {
     TE.fixed <- NA
     seTE.fixed <- NA
@@ -1464,7 +1496,6 @@ metagen <- function(TE, seTE, studlab,
     lower.random <- NA
     upper.random <- NA
     w.random <- rep(0, k.all)
-    ##
     if (hakn)
       df.hakn <- NA
     ##
@@ -1533,9 +1564,38 @@ metagen <- function(TE, seTE, studlab,
     ## Hartung-Knapp adjustment
     ##
     if (hakn) {
-      seTE.random <- sqrt(1 / (k - 1) * sum(w.random * (TE - TE.random)^2 /
-                                              sum(w.random), na.rm = TRUE))
       df.hakn <- k - 1
+      q <- 1 / (k - 1) * sum(w.random * (TE - TE.random)^2, na.rm = TRUE)
+      ##
+      seTE.random <- sqrt(q / sum(w.random))
+      ##
+      if (adhoc.hakn == "se") {
+        ##
+        ## Variance correction if SE_HK < SE_notHK (Knapp and Hartung, 2003)
+        ##
+        if (q < 1)
+          seTE.random.hakn.orig <- seTE.random
+        seTE.random <- sqrt(max(q, 1) /  sum(w.random))
+      }
+      else if (adhoc.hakn == "ci") {
+        ##
+        ## Variance correction if CI_HK < CI_DL (IQWiG, 2020)
+        ##
+        ci.hk <- ci(TE.random, seTE.random, level = level.comb, df = df.hakn)
+        ##
+        m.dl <- metagen(TE, seTE, method.tau = "DL", method.tau.ci = "",
+                        hakn = FALSE)
+        ci.dl <- ci(m.dl$TE.random, m.dl$seTE.random, level = level.comb)
+        ##
+        width.hk <- ci.hk$upper - ci.hk$lower
+        width.dl <- ci.dl$upper - ci.dl$lower
+        ##
+        if (width.hk < width.dl) {
+          seTE.random.hakn.orig <- seTE.random
+          seTE.random <- sqrt(max(q, 1) /  sum(w.random))
+        }
+      }
+      ##
       ci.r <- ci(TE.random, seTE.random, level = level.comb, df = df.hakn,
                  null.effect = null.effect)
     }
@@ -1623,8 +1683,9 @@ metagen <- function(TE, seTE, studlab,
               comb.random = comb.random,
               overall = overall,
               overall.hetstat = overall.hetstat,
-              hakn = hakn,
+              hakn = hakn, adhoc.hakn = adhoc.hakn,
               df.hakn = if (hakn) df.hakn else NULL,
+              seTE.random.hakn.orig = seTE.random.hakn.orig,
               method.tau = method.tau, method.tau.ci = method.tau.ci,
               tau.preset = tau.preset,
               TE.tau = if (!missing(TE.tau) & method.tau == "DL") TE.tau else NULL,
