@@ -55,6 +55,9 @@
 #' \item{hakn}{A logical indicating whether the method by Hartung and
 #'   Knapp is used to adjust test statistics and confidence
 #'   intervals.}
+#' \item{adhoc.hakn}{A character string indicating whether \emph{ad
+#'   hoc} variance correction should be used for Hartung-Knapp
+#'   method.}
 #' \item{method.tau}{A character string indicating which method is
 #'   used to estimate the between-study variance \eqn{\tau^2}.}
 #' \item{tau.preset}{Prespecified value for the square root of the
@@ -236,7 +239,7 @@ metainf <- function(x, pooled, sortvar) {
                    ##
                    level.comb = x$level.comb,
                    ##
-                   hakn = x$hakn,
+                   hakn = x$hakn, adhoc.hakn = x$adhoc.hakn,
                    method.tau = x$method.tau,
                    tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                    ##
@@ -255,7 +258,7 @@ metainf <- function(x, pooled, sortvar) {
                     ##
                     level.comb = x$level.comb,
                     ##
-                    hakn = x$hakn,
+                    hakn = x$hakn, adhoc.hakn = x$adhoc.hakn,
                     method.tau = x$method.tau,
                     tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                     ##
@@ -273,7 +276,7 @@ metainf <- function(x, pooled, sortvar) {
                    ##
                    level.comb = x$level.comb,
                    ##
-                   hakn = x$hakn,
+                   hakn = x$hakn, adhoc.hakn = x$adhoc.hakn,
                    method.tau = x$method.tau,
                    tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                    ##
@@ -290,7 +293,7 @@ metainf <- function(x, pooled, sortvar) {
                    ##
                    level.comb = x$level.comb,
                    ##
-                   hakn = x$hakn,
+                   hakn = x$hakn, adhoc.hakn = x$adhoc.hakn,
                    method.tau = x$method.tau,
                    tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                    ##
@@ -312,7 +315,8 @@ metainf <- function(x, pooled, sortvar) {
                    ##
                    level.comb = x$level.comb,
                    ##
-                   hakn = x$hakn, method.tau = x$method.tau,
+                   hakn = x$hakn, adhoc.hakn = x$adhoc.hakn,
+                   method.tau = x$method.tau,
                    tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                    ##
                    keepdata = FALSE,
@@ -329,7 +333,7 @@ metainf <- function(x, pooled, sortvar) {
                     ##
                     level.comb = x$level.comb,
                     ##
-                    hakn = x$hakn,
+                    hakn = x$hakn, adhoc.hakn = x$adhoc.hakn,
                     method.tau = x$method.tau,
                     tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                     ##
@@ -350,7 +354,7 @@ metainf <- function(x, pooled, sortvar) {
                     ##
                     level.comb = x$level.comb,
                     ##
-                    hakn = x$hakn,
+                    hakn = x$hakn, adhoc.hakn = x$adhoc.hakn,
                     method.tau = x$method.tau,
                     tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                     ##
@@ -370,7 +374,7 @@ metainf <- function(x, pooled, sortvar) {
                     ##
                     level.comb = x$level.comb,
                     ##
-                    hakn = x$hakn,
+                    hakn = x$hakn, adhoc.hakn = x$adhoc.hakn,
                     method.tau = x$method.tau,
                     tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                     ##
@@ -535,7 +539,7 @@ metainf <- function(x, pooled, sortvar) {
               ##
               Q = NA,
               level.comb = x$level.comb,
-              hakn = x$hakn,
+              hakn = x$hakn, adhoc.hakn = x$adhoc.hakn,
               method.tau = x$method.tau,
               tau.preset = x$tau.preset,
               TE.tau = x$TE.tau,
