@@ -23,17 +23,26 @@
 #' \code{\link{forest.meta}}.
 #' 
 #' The function can be used to either change individual settings (see
-#' Examples) or use one of the following general settings: %%
-#' \itemize{ \item \code{settings.meta("revman5")} \item
-#' \code{settings.meta("jama")} } The first command can be used to
-#' reproduce meta-analyses from Cochrane reviews conducted with
-#' \emph{Review Manager 5} (RevMan 5,
+#' Examples) or use one of the following general settings:
+#' \itemize{
+#' \item \code{settings.meta("revman5")}
+#' \item \code{settings.meta("jama")}
+#' \item \code{settings.meta("iqwig5")}
+#' \item \code{settings.meta("iqwig6")}
+#' }
+#'
+#' The first command can be used to reproduce meta-analyses from
+#' Cochrane reviews conducted with \emph{Review Manager 5} (RevMan 5,
 #' \url{http://community.cochrane.org/tools/review-production-tools/revman-5})
 #' and specifies to use a RevMan 5 layout in forest plots. The second
 #' command can be used to generate forest plots following instructions
 #' for authors of the \emph{Journal of the American Medical
 #' Association}
-#' (\url{http://jamanetwork.com/journals/jama/pages/instructions-for-authors}).
+#' (\url{http://jamanetwork.com/journals/jama/pages/instructions-for-authors}). The
+#' other two commands implement the recommendations of the Institute
+#' for Quality and Efficiency in Health Care, Germany (IQWiG)
+#' accordinging to General Methods 5 and 6, respectively
+#' (\url{https://www.iqwig.de/en/methods/methods-paper.3020.html}).
 #' 
 #' RevMan 5 settings, in detail:
 #' \tabular{lll}{
@@ -76,6 +85,23 @@
 #'   (for 0.001 < p \eqn{\le} 0.01) or two digits (p > 0.01)
 #' }
 #' 
+#' IQWiG, General Methods 5 settings:
+#' \tabular{lll}{
+#' \bold{Argument} \tab \bold{Value} \tab \bold{Comment} \cr
+#' \code{hakn} \tab TRUE \tab Hartung-Knapp method \cr
+#' \code{prediction} \tab TRUE \tab Prediction interval \cr
+#' }
+#' 
+#' IQWiG, General Methods 6 settings:
+#' \tabular{lll}{
+#' \bold{Argument} \tab \bold{Value} \tab \bold{Comment} \cr
+#' \code{hakn} \tab TRUE \tab Hartung-Knapp method \cr
+#' \code{adhoc.hakn} \tab TRUE \tab \emph{ad hoc} variance correction \cr
+#' \code{method.tau} \tab "PM" \tab Paule-Mandel estimator for
+#'   between-study variance \cr
+#' \code{prediction} \tab TRUE \tab Prediction interval \cr
+#' }
+#' 
 #' A list of all arguments with current settings is printed using the
 #' command \code{settings.meta("print")}.
 #' 
@@ -184,7 +210,8 @@ settings.meta <- function(...) {
   res$sm4bin <- res$sm4cont <- res$sm4cor <- res$sm4inc <-
     res$sm4mean <- res$sm4prop <- res$sm4rate <- NULL
   res$ci4prop <- NULL
-  res$meth4tau <- res$meth4tau.ci <- NULL
+  res$meth4bin <- res$meth4tau <- res$meth4tau.ci <- NULL
+  res$adhoc4hakn <- NULL
   res$argslist <- NULL
   res$Wan2014.Table1 <- res$Wan2014.Table2 <- NULL
   
@@ -252,7 +279,7 @@ settings.meta <- function(...) {
   }
   
   
-  settings <- c("RevMan5", "JAMA", "IQWiG4.2", "meta4")
+  settings <- c("RevMan5", "JAMA", "IQWiG5", "IQWiG6", "meta4")
   layouts <- c(settings[1:2], "meta")
   
   
@@ -343,6 +370,7 @@ settings.meta <- function(...) {
     catarg("comb.fixed     ")
     catarg("comb.random    ")
     catarg("hakn           ")
+    catarg("adhoc.hakn     ")
     catarg("method.tau     ")
     catarg("tau.common     ")
     catarg("prediction     ")
@@ -442,6 +470,7 @@ settings.meta <- function(...) {
     setOption("comb.fixed", TRUE)
     setOption("comb.random", TRUE)
     setOption("hakn", FALSE)
+    setOption("adhoc.hakn", "")
     setOption("method.tau", "DL")
     setOption("tau.common", FALSE)
     setOption("prediction", FALSE)
@@ -520,7 +549,7 @@ settings.meta <- function(...) {
   else if (specific.settings) {
     ##
     ## Remember:
-    ## settings <- c("RevMan5", "JAMA", "IQWiG4.2", "meta4")
+    ## settings <- c("RevMan5", "JAMA", "IQWiG5", "IQWiG6", "meta4")
     ##
     if (setting == "RevMan5") {
       specificSetting(args = c("hakn", "method.tau", "tau.common",
@@ -552,12 +581,17 @@ settings.meta <- function(...) {
                       setting = "JAMA settings")
     }
     ##
-    else if (setting == "IQWiG4.2") {
-      specificSetting(args = c("hakn", "method.tau", "RR.Cochrane",
-                               "Q.Cochrane"),
-                      new = list(TRUE, "PM", FALSE,
-                                 FALSE),
-                      setting = "IQWiG 4.2 settings")
+    else if (setting == "IQWiG5") {
+      specificSetting(args = c("hakn", "prediction"),
+                      new = list(TRUE, TRUE),
+                      setting = "IQWiG 5 settings")
+    }
+    ##
+    else if (setting == "IQWiG6") {
+      specificSetting(args = c("hakn", "adhoc.hakn",
+                               "method.tau", "prediction"),
+                      new = list(TRUE, "ci", "PM", TRUE),
+                      setting = "IQWiG 6 settings")
     }
     ##
     else if (setting == "meta4") {
@@ -584,6 +618,7 @@ settings.meta <- function(...) {
     idcomb.fixed <- argid(names, "comb.fixed")
     idcomb.random <- argid(names, "comb.random")
     idhakn <- argid(names, "hakn")
+    idadhoc.hakn <- argid(names, "adhoc.hakn")
     idmethod.tau <- argid(names, "method.tau")
     idtau.common <- argid(names, "tau.common")
     idprediction <- argid(names, "prediction")
@@ -686,6 +721,11 @@ settings.meta <- function(...) {
       chklogical(hakn)
       setOption("hakn", hakn)
     }
+    if (!is.na(idadhoc.hakn)) {
+      adhoc.hakn <- args[[idadhoc.hakn]]
+      adhoc.hakn <- setchar(adhoc.hakn, .settings$adhoc4hakn)
+      setOption("adhoc.hakn", adhoc.hakn)
+    }
     if (!is.na(idmethod.tau)) {
       method.tau <- args[[idmethod.tau]]
       method.tau <- setchar(method.tau, .settings$meth4tau)
@@ -901,7 +941,7 @@ settings.meta <- function(...) {
     }
     if (!is.na(idmethod)) {
       method <- args[[idmethod]]
-      method <- setchar(method, c("Inverse", "MH", "Peto", "GLMM"))
+      method <- setchar(method, .settings$meth4bin)
       setOption("method", method)
     }
     if (!is.na(idmodel.glmm)) {
