@@ -222,91 +222,6 @@
 #' 
 #' trimfill(m1$TE, m1$seTE, sm = m1$sm)
 #' 
-#' @rdname trimfill
-#' @export trimfill
-
-
-trimfill <- function(x, ...)
-  UseMethod("trimfill")
-
-
-
-
-
-#' @rdname trimfill
-#' @method trimfill default
-#' @export
-#' @export trimfill.default
-
-
-trimfill.default <- function(x, seTE, left = NULL, ma.fixed = TRUE,
-                             type = "L", n.iter.max = 50,
-                             sm = "", studlab = NULL,
-                             level = 0.95, level.comb = level,
-                             comb.fixed = FALSE, comb.random = TRUE,
-                             hakn = FALSE,
-                             method.tau = "DL",
-                             method.tau.ci = if (method.tau == "DL") "J" else "QP",
-                             prediction = FALSE, level.predict = level,
-                             backtransf = TRUE, pscale = 1,
-                             irscale = 1, irunit = "person-years",
-                             silent = TRUE, ...) {
-  
-  
-  ##
-  ##
-  ## (1) Check essential arguments
-  ##
-  ##
-  k.All <- length(x)
-  ##
-  chknumeric(x)
-  chknumeric(seTE)
-  chknull(sm)
-  ##
-  fun <- "trimfill"
-  chklength(seTE, k.All, fun)
-  ##
-  if (!is.null(studlab))
-    chklength(studlab, k.All, fun)
-  else
-    studlab <- seq(along = x)
-  ##
-  if (is.null(sm)) sm <- ""
-  
-  
-  ##
-  ##
-  ## (2) Do meta-analysis
-  ##
-  ##
-  m <- metagen(x, seTE, studlab = studlab, sm = sm, method.tau.ci = "")
-  
-  
-  ##
-  ##
-  ## (3) Run trim-and-fill method
-  ##
-  ##
-  res <- trimfill(m, left = left, ma.fixed = ma.fixed,
-                  type = type, n.iter.max = n.iter.max,
-                  level = level, level.comb = level.comb,
-                  comb.fixed = comb.fixed, comb.random = TRUE,
-                  hakn = hakn,
-                  method.tau = method.tau, method.tau.ci = method.tau.ci,
-                  prediction = prediction, level.predict = level.predict,
-                  backtransf = backtransf, pscale = pscale,
-                  irscale = irscale, irunit = irunit,
-                  silent = silent, ...)
-  
-  
-  res
-}
-
-
-
-
-
 #' @rdname trimfill
 #' @method trimfill meta
 #' @export
@@ -828,3 +743,77 @@ trimfill.meta <- function(x, left = NULL, ma.fixed = TRUE,
   ##
   res
 }
+
+
+
+
+
+#' @rdname trimfill
+#' @method trimfill default
+#' @export
+#' @export trimfill.default
+
+
+trimfill.default <- function(x, seTE, left = NULL, ma.fixed = TRUE,
+                             type = "L", n.iter.max = 50,
+                             sm = "", studlab = NULL,
+                             level = 0.95, level.comb = level,
+                             comb.fixed = FALSE, comb.random = TRUE,
+                             hakn = FALSE,
+                             method.tau = "DL",
+                             method.tau.ci = if (method.tau == "DL") "J" else "QP",
+                             prediction = FALSE, level.predict = level,
+                             backtransf = TRUE, pscale = 1,
+                             irscale = 1, irunit = "person-years",
+                             silent = TRUE, ...) {
+  
+  
+  ##
+  ##
+  ## (1) Check essential arguments
+  ##
+  ##
+  k.All <- length(x)
+  ##
+  chknumeric(x)
+  chknumeric(seTE)
+  chknull(sm)
+  ##
+  fun <- "trimfill"
+  chklength(seTE, k.All, fun)
+  ##
+  if (!is.null(studlab))
+    chklength(studlab, k.All, fun)
+  else
+    studlab <- seq(along = x)
+  ##
+  if (is.null(sm)) sm <- ""
+  
+  
+  ##
+  ##
+  ## (2) Do meta-analysis
+  ##
+  ##
+  m <- metagen(x, seTE, studlab = studlab, sm = sm, method.tau.ci = "")
+  
+  
+  ##
+  ##
+  ## (3) Run trim-and-fill method
+  ##
+  ##
+  res <- trimfill(m, left = left, ma.fixed = ma.fixed,
+                  type = type, n.iter.max = n.iter.max,
+                  level = level, level.comb = level.comb,
+                  comb.fixed = comb.fixed, comb.random = TRUE,
+                  hakn = hakn,
+                  method.tau = method.tau, method.tau.ci = method.tau.ci,
+                  prediction = prediction, level.predict = level.predict,
+                  backtransf = backtransf, pscale = pscale,
+                  irscale = irscale, irunit = irunit,
+                  silent = silent, ...)
+  
+  
+  res
+}
